from indep_free.manager import download_newspaper
from pathlib import Path


def main():
    # Need customize work
    folder = Path('/usr/share/indep_free/')
    download_newspaper(folder, False)
    return True


if __name__ == '__main__':
    main()



from datetime import date
from indep_free.downloader import get_newspaper
from typing import Union
from requests import Response
from pathlib import Path
from indep_free.mailer import send_mail


def get_current_date() -> str:
    "Get the current date in the format %Y%m%d"
    today = date.today()
    return date.strftime(today, '%Y%m%d')


def save_file(pdf: Response,
              filename: Path) -> bool:
    with open(filename, 'wb') as f:
        f.write(pdf.content)
    return True


def download_newspaper(download_folder: str,
                       remove_np_after_download: bool = True,
                       d_to_download: Union[bool, date] = False) -> bool:
    if d_to_download or remove_np_after_download:
        raise NotImplementedError
    else:
        date_to_download = get_current_date()

    pdf = get_newspaper(date_to_download)
    filename = date_to_download + date_to_download + '.pdf'

    save_file(pdf, filename)
    send_mail(filename, date_to_download)
    return True



import subprocess

from pathlib import Path
from indep_free.utils import (
    MAIL_SUBJECT,
    TO_MAIL_LIST,
)


def get_message(date_to_download: str) -> str:
    return 'Buenas\n\n Este mail corresponde al envío del diario con fecha '\
           f'{date_to_download}\n\nSaludos!'


def send_mail(path: Path, date_to_download: str) -> bool:
    for email in TO_MAIL_LIST:
        cmd = ["mutt", "-a", path, "-s", MAIL_SUBJECT, email, "<",
               get_message(date_to_download)]

        subprocess.call(cmd)
    return True




import requests
from indep_free.utils import URL_NEWSPAPER

class NotGetNewspaper(Exception):
    """"""
    def __init__(self, code, *args, **kwargs):
        self.message = f"I cannot get newspaper. Code error: {code}"
        super().__init__(self.message, *args, **kwargs)


def get_newspaper(name: str) -> requests.Response:
    """Download the newspaper with *name* into the *folder* directory.
    """
    pdf = requests.get(URL_NEWSPAPER.format(name), allow_redirects=True)
    if not pdf.ok:
        raise NotGetNewspaper(pdf.status_code)
    return pdf




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['indep_free']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.25.1,<3.0.0']

entry_points = \
{'console_scripts': ['indep_free = indep_free.cli:main']}

setup_kwargs = {
    'name': 'indep-free',
    'version': '0.2.0',
    'description': 'Send newspaper "El Independiente" to mail. While we can download the newspaper and sed via email.',
    'long_description': None,
    'author': 'Emmanuel Arias',
    'author_email': 'eamanu@yaerobi.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
